@@ -1,16 +1,17 @@
 package Geo::GoogleEarth::Document;
 use strict;
 use base qw{Geo::GoogleEarth::Document::Folder}; 
+use Geo::GoogleEarth::Document::Style;
 use XML::Simple qw{};
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION     = '0.08';
+    $VERSION     = '0.09';
 }
 
 =head1 NAME
 
-Geo::GoogleEarth::Document - Creates a GoogleEarth KML Document
+Geo::GoogleEarth::Document - Generates GoogleEarth KML Documents
 
 =head1 SYNOPSIS
 
@@ -19,6 +20,7 @@ Geo::GoogleEarth::Document - Creates a GoogleEarth KML Document
   my $folder      = $document->Folder();                #Geo::GoogleEarth::Document::Folder object
   my $placemark   = $document->Placemark();             #Geo::GoogleEarth::Document::Placemark object
   my $networklink = $document->NetworkLink();           #Geo::GoogleEarth::Document::NetworkLink object
+  my $style = $document->Style();                       #Geo::GoogleEarth::Document::Style object
   print $document->render();
 
 =head1 DESCRIPTION
@@ -51,6 +53,22 @@ sub render {
   return $xs->XMLout($self->structure);
 }
 
+=head2 Style
+
+Constructs a new Style object and appends it to the document object.  Returns the object reference.
+
+  my $style=$document->Style(id=>"myicon1",
+                 iconHref=>"http://maps.google.com/mapfiles/kml/paddle/L.png");
+
+=cut
+
+sub Style {
+  my $self=shift();
+  my $obj=Geo::GoogleEarth::Document::Style->new(@_);
+  $self->data($obj);
+  return $obj;
+}
+
 =head1 BUGS
 
 =head1 SUPPORT
@@ -83,6 +101,8 @@ L<Geo::GoogleEarth::Document::NetworkLink> is a Geo::GoogleEarth::Document  Netw
 
 L<Geo::GoogleEarth::Document::Placemark> is a Geo::GoogleEarth::Document Placemark object.
 
+L<Geo::GoogleEarth::Document::Style> is a Geo::GoogleEarth::Document Style object.
+
 L<XML::Simple> is used by this package to generate XML from a data structure.
 
 =cut
